@@ -1,10 +1,16 @@
 from typing import Callable, Optional
 from dataclasses import dataclass
 import pymich.middle_end.ir.instr_types as t
-from pymich.middle_end.ir.instr_types import StdlibVariable, StdlibFunctionSpec, StdLibClassSpec, MultiArgFunctionPrototype
+from pymich.middle_end.ir.instr_types import (
+    StdlibVariable,
+    StdlibFunctionSpec,
+    StdLibClassSpec,
+    MultiArgFunctionPrototype,
+)
 
 
-identity = lambda x: x
+def identity(x):
+    return x
 
 
 @dataclass
@@ -49,10 +55,7 @@ class StdLibCompileCallbacks:
 
 
 class StdLib:
-    def __init__(
-            self,
-            compile_callbacks: Optional[StdLibCompileCallbacks] = None
-    ):
+    def __init__(self, compile_callbacks: Optional[StdLibCompileCallbacks] = None):
         if not compile_callbacks:
             compile_callbacks = StdLibCompileCallbacks()
 
@@ -80,7 +83,7 @@ class StdLib:
             "abs": self.abs(),
             "datetime": datetime_object,
             "timedelta": self.timedelta(),
-            "breakpoint": self.breakpoint(),
+            "breakpoint": self.breakpoint(),  # noqa: T100
             "transaction": self.transaction(),
             "Contract": self.contract(),
             "Bytes": bytes_object,
@@ -116,21 +119,21 @@ class StdLib:
             lambda element_types: MultiArgFunctionPrototype(
                 [element_types[0]],
                 t.Option(element_types[0]),
-            )
+            ),
         )
         option_get = StdlibFunctionSpec(
             self.compile_callbacks.compile_option_get,
             lambda el_type: MultiArgFunctionPrototype(
                 [t.PythonString()],
                 el_type.option_type,
-            )
+            ),
         )
         option_get_with_default = StdlibFunctionSpec(
             self.compile_callbacks.compile_option_get_with_default,
             lambda el_type: MultiArgFunctionPrototype(
                 [el_type.option_type],
                 el_type.option_type,
-            )
+            ),
         )
         option_object = StdLibClassSpec()
         option_object.create_constructor(option_constructor)
@@ -145,14 +148,14 @@ class StdLib:
             lambda element_types: MultiArgFunctionPrototype(
                 [t.Spread(element_types[0])],
                 t.List(element_types[0]),
-            )
+            ),
         )
         list_prepend = StdlibFunctionSpec(
             self.compile_callbacks.list_prepend,
             lambda el_type: MultiArgFunctionPrototype(
                 [el_type],
                 t.List(el_type),
-            )
+            ),
         )
         list_object = StdLibClassSpec()
         list_object.create_constructor(list_constructor)
@@ -164,8 +167,12 @@ class StdLib:
         def big_map_constructor_cb(element_types):
             return MultiArgFunctionPrototype(
                 [t.Unit()],
-                t.BigMap(element_types[0].get_attribute_type("0"), element_types[0].get_attribute_type("1")),
+                t.BigMap(
+                    element_types[0].get_attribute_type("0"),
+                    element_types[0].get_attribute_type("1"),
+                ),
             )
+
         big_map_constructor = StdlibFunctionSpec(
             self.compile_callbacks.big_map,
             big_map_constructor_cb,
@@ -175,14 +182,14 @@ class StdLib:
             lambda el_type: MultiArgFunctionPrototype(
                 [el_type],
                 t.BigMap(el_type.key_type, el_type.value_type),
-            )
+            ),
         )
         big_map_get = StdlibFunctionSpec(
             self.compile_callbacks.dict_safe,
             lambda big_map_type: MultiArgFunctionPrototype(
                 [big_map_type.key_type],
                 big_map_type.value_type,
-            )
+            ),
         )
         big_map_object = StdLibClassSpec()
         big_map_object.create_constructor(big_map_constructor)
@@ -197,21 +204,21 @@ class StdLib:
             lambda element_types: MultiArgFunctionPrototype(
                 [t.Spread(element_types[0])],
                 t.Set(element_types[0]),
-            )
+            ),
         )
         set_add = StdlibFunctionSpec(
             self.compile_callbacks.set_add,
             lambda el_type: MultiArgFunctionPrototype(
                 [el_type],
                 t.Set(el_type),
-            )
+            ),
         )
         set_remove = StdlibFunctionSpec(
             self.compile_callbacks.set_remove,
             lambda el_type: MultiArgFunctionPrototype(
                 [el_type],
                 t.Set(el_type),
-            )
+            ),
         )
         set_object = StdLibClassSpec()
         set_object.create_constructor(set_constructor)
@@ -225,22 +232,25 @@ class StdLib:
             self.compile_callbacks.map,
             lambda element_types: MultiArgFunctionPrototype(
                 [t.Unit()],
-                t.Dict(element_types[0].get_attribute_type("0"), element_types[0].get_attribute_type("1")),
-            )
+                t.Dict(
+                    element_types[0].get_attribute_type("0"),
+                    element_types[0].get_attribute_type("1"),
+                ),
+            ),
         )
         map_set = StdlibFunctionSpec(
             self.compile_callbacks.map_set,
             lambda el_type: MultiArgFunctionPrototype(
                 [el_type],
                 t.Dict(el_type.key_type, el_type.value_type),
-            )
+            ),
         )
         map_get = StdlibFunctionSpec(
             self.compile_callbacks.dict_safe,
             lambda map_type: MultiArgFunctionPrototype(
                 [map_type.key_type],
                 map_type.value_type,
-            )
+            ),
         )
         map_object = StdLibClassSpec()
         map_object.create_constructor(map_constructor)
@@ -279,42 +289,26 @@ class StdLib:
     def balance(self):
         return StdlibVariable(t.Mutez(), self.compile_callbacks.balance)
 
-    def unit(self):
-        return StdlibVariable(t.Unit(), self.compile_callbacks.unit)
-
     def unit(self):
         return StdlibFunctionSpec(
             self.compile_callbacks.unit,
-            lambda _: MultiArgFunctionPrototype(
-                _,
-                t.Unit()
-            )
+            lambda _: MultiArgFunctionPrototype([], t.Unit()),
         )
 
     def breakpoint(self):
         return StdlibFunctionSpec(
             self.compile_callbacks.compile_breakpoint,
-            lambda: MultiArgFunctionPrototype(
-                [t.Unit()],
-                t.Unit()
-            )
+            lambda: MultiArgFunctionPrototype([t.Unit()], t.Unit()),
         )
 
-
     def timestamp(self):
         timestamp_constructor = StdlibFunctionSpec(
             self.compile_callbacks.datetime_from_timestamp,
-            lambda _: MultiArgFunctionPrototype(
-                [t.PythonInt()],
-                t.Datetime()
-            )
+            lambda _: MultiArgFunctionPrototype([t.PythonInt()], t.Datetime()),
         )
         timestamp_now = StdlibFunctionSpec(
             self.compile_callbacks.datetime_now,
-            lambda _: MultiArgFunctionPrototype(
-                [t.Unit()],
-                t.Datetime()
-            )
+            lambda _: MultiArgFunctionPrototype([t.Unit()], t.Datetime()),
         )
         timestamp_object = StdLibClassSpec()
         timestamp_object.create_constructor(timestamp_constructor)
@@ -327,16 +321,19 @@ class StdLib:
         datetime_constructor = StdlibFunctionSpec(
             self.compile_callbacks.datetime,
             lambda _: MultiArgFunctionPrototype(
-                [t.PythonInt(), t.PythonInt(), t.PythonInt(), t.PythonInt(), t.PythonInt()],
-                t.Datetime()
-            )
+                [
+                    t.PythonInt(),
+                    t.PythonInt(),
+                    t.PythonInt(),
+                    t.PythonInt(),
+                    t.PythonInt(),
+                ],
+                t.Datetime(),
+            ),
         )
         datetime_now = StdlibFunctionSpec(
             self.compile_callbacks.datetime_now,
-            lambda _: MultiArgFunctionPrototype(
-                [t.Unit()],
-                t.Datetime()
-            ),
+            lambda _: MultiArgFunctionPrototype([t.Unit()], t.Datetime()),
         )
         datetime_object = StdLibClassSpec()
         datetime_object.create_constructor(datetime_constructor)
@@ -350,7 +347,7 @@ class StdLib:
             lambda dict_type: MultiArgFunctionPrototype(
                 [t.Unit()],
                 dict_type.value_type,
-            )
+            ),
         )
         dict_object = StdLibClassSpec()
         dict_object.create_method("get", dict_get)
@@ -359,33 +356,21 @@ class StdLib:
     def abs(self):
         return StdlibFunctionSpec(
             self.compile_callbacks.abs,
-            lambda: MultiArgFunctionPrototype(
-                [t.Int()],
-                t.Nat()
-            )
+            lambda: MultiArgFunctionPrototype([t.Int()], t.Nat()),
         )
 
     def bytes(self):
         bytes_constructor = StdlibFunctionSpec(
             self.compile_callbacks.pack,
-            lambda _: MultiArgFunctionPrototype(
-                [t.Unknown()],
-                t.Bytes()
-            )
+            lambda _: MultiArgFunctionPrototype([t.Unknown()], t.Bytes()),
         )
         bytes_unpack = StdlibFunctionSpec(
             self.compile_callbacks.unpack,
-            lambda ty: MultiArgFunctionPrototype(
-                [ty],
-                ty
-            )
+            lambda ty: MultiArgFunctionPrototype([ty], ty),
         )
         bytes_blake2b = StdlibFunctionSpec(
             self.compile_callbacks.blake2b,
-            lambda _: MultiArgFunctionPrototype(
-                [t.Unit()],
-                t.Bytes()
-            )
+            lambda _: MultiArgFunctionPrototype([t.Unit()], t.Bytes()),
         )
 
         bytes_object = StdLibClassSpec()
@@ -399,18 +384,16 @@ class StdLib:
         return StdlibFunctionSpec(
             self.compile_callbacks.timedelta,
             lambda: MultiArgFunctionPrototype(
-                [t.Int(), t.Int(), t.Int(), t.Int(), t.Int()],
-                t.Int()
-            )
+                [t.Int(), t.Int(), t.Int(), t.Int(), t.Int()], t.Int()
+            ),
         )
 
     def transaction(self):
         return StdlibFunctionSpec(
             self.compile_callbacks.transaction,
             lambda contract_type: MultiArgFunctionPrototype(
-                [t.Contract([contract_type]), t.Mutez(), contract_type],
-                t.Operation()
-            )
+                [t.Contract([contract_type]), t.Mutez(), contract_type], t.Operation()
+            ),
         )
 
     def operations(self):
@@ -419,7 +402,7 @@ class StdLib:
             lambda contract_type: MultiArgFunctionPrototype(
                 [t.Contract(contract_type), t.Mutez(), contract_type],
                 t.Operations(),
-            )
+            ),
         )
 
         operations_object = StdLibClassSpec()
@@ -431,31 +414,27 @@ class StdLib:
         return StdlibFunctionSpec(
             self.compile_callbacks.contract,
             lambda contract_type: MultiArgFunctionPrototype(
-                [t.Address()],
-                t.Contract(contract_type)
-            )
+                [t.Address()], t.Contract(contract_type)
+            ),
         )
 
     def mutez(self):
         return StdlibFunctionSpec(
             self.compile_callbacks.mutez,
-            lambda: MultiArgFunctionPrototype([t.PythonInt()], t.Mutez())
+            lambda: MultiArgFunctionPrototype([t.PythonInt()], t.Mutez()),
         )
 
     def nat(self):
         nat_constructor = StdlibFunctionSpec(
             self.compile_callbacks.nat,
-            lambda _: MultiArgFunctionPrototype(
-                [t.PythonInt()],
-                t.Nat()
-            )
+            lambda _: MultiArgFunctionPrototype([t.PythonInt()], t.Nat()),
         )
         to_int = StdlibFunctionSpec(
             self.compile_callbacks.to_int,
             lambda _: MultiArgFunctionPrototype(
                 [t.Unit()],
                 t.Int(),
-            )
+            ),
         )
 
         nat_object = StdLibClassSpec()
@@ -467,17 +446,14 @@ class StdLib:
     def int(self):
         int_constructor = StdlibFunctionSpec(
             self.compile_callbacks.int,
-            lambda _: MultiArgFunctionPrototype(
-                [t.PythonInt()],
-                t.Int()
-            )
+            lambda _: MultiArgFunctionPrototype([t.PythonInt()], t.Int()),
         )
         is_nat = StdlibFunctionSpec(
             self.compile_callbacks.is_nat,
             lambda _: MultiArgFunctionPrototype(
                 [t.Unit()],
                 t.Option(t.Nat()),
-            )
+            ),
         )
 
         int_object = StdLibClassSpec()
@@ -489,17 +465,11 @@ class StdLib:
     def string(self):
         return StdlibFunctionSpec(
             self.compile_callbacks.string,
-            lambda: MultiArgFunctionPrototype(
-                [t.PythonString()],
-                t.String()
-            )
+            lambda: MultiArgFunctionPrototype([t.PythonString()], t.String()),
         )
 
     def address(self):
         return StdlibFunctionSpec(
             self.compile_callbacks.address,
-            lambda: MultiArgFunctionPrototype(
-                [t.PythonString()],
-                t.Address()
-            )
+            lambda: MultiArgFunctionPrototype([t.PythonString()], t.Address()),
         )
