@@ -8,17 +8,23 @@ class CompilerException(Exception):
     def __init__(self, message, lineno):
         self.message = message + f" at line {lineno}"
 
+
 class NotAnIterableException(CompilerException):
     def __init__(self, actual_type):
         self.message = f"{actual_type} is not an iterable"
 
+
 class MalformedAnnotationException(CompilerException):
     def __init__(self, message):
         self.message = message
 
+
 class TypeException(CompilerException):
     def __init__(self, expected_type, actual_type, lineno):
-        self.message = f"Unexpected type: expected {expected_type}, got {actual_type} at line {lineno}"
+        self.message = f"""Unexpected type at line {lineno}:
+  - expected {expected_type},
+  - got {actual_type}"""
+
 
 class OperandException(CompilerException):
     def __init__(self, instr_name, allowed_types, actual_types, extra_msg="", lineno=0):
@@ -30,25 +36,34 @@ class OperandException(CompilerException):
         if extra_msg:
             self.message += f"\n\n N.B. {extra_msg}"
 
+
 class AttributeException(TypeException):
     def __init__(self, record_type, attribute_name, lineno):
-        self.message = f"{record_type} Record has no attribute {attribute_name} at line {lineno}"
+        self.message = (
+            f"{record_type} Record has no attribute {attribute_name} at line {lineno}"
+        )
+
 
 class NameException(TypeException):
     def __init__(self, token_name, lineno):
         self.message = f"Variable '{token_name}' does not exist at line {lineno}"
 
+
 class FunctionNameException(TypeException):
     def __init__(self, function_name, lineno):
         self.message = f"Function '{function_name}' does not exist at line {lineno}"
 
+
 class FunctionParameterTypeException(TypeException):
     def __init__(self, expected_type, actual_type, lineno):
-        self.message = f"Function expected parameters of type {expected_type} but got {actual_type} at line {lineno}"
+        self.message = f"Function expected parameters of type {expected_type}"
+        self.message += f" but got {actual_type} at line {lineno}"
+
 
 class TypeAnnotationDoesNotExistException(TypeException):
     def __init__(self, annotation_name, expected_type_annotations, lineno):
-        self.message = f"Type annotation '{annotation_name}' does not exist, expected {expected_type_annotations} at line {lineno}"
+        self.message = f"Type annotation '{annotation_name}' does not exist,"
+        self.message += f" expected {expected_type_annotations} at line {lineno}"
 
 
 class ConditionBranchesTypeMismatch(CompilerException):
@@ -69,6 +84,7 @@ class MichelsonTypecheckerException(Exception):
     def __init__(self, message, lineno=0):
         self.message = message + f" at line {lineno}"
 
+
 class StackTopTypeException(MichelsonTypecheckerException):
     def __init__(self, instr_name, expected_type, actual_type, extra_msg="", lineno=0):
         self.message = f"""Top stack type mismatch when calling {instr_name}:
@@ -80,6 +96,7 @@ N.B. {extra_msg}
 Hint: stack grows this way: [stack_bottom, ..., stack_top] ---->
         """
 
+
 class SetElementTypeException(MichelsonTypecheckerException):
     def __init__(self, el_type, set_type, lineno=0):
         self.message = f"""Element type incompatible with set type:
@@ -87,6 +104,7 @@ class SetElementTypeException(MichelsonTypecheckerException):
   - set type: {set_type}
         """
 
+
 class MapKeyTypeException(MichelsonTypecheckerException):
     def __init__(self, key_type, map_type, lineno=0):
         self.message = f"""Key type incompatible with map type on GET instruction:
@@ -94,9 +112,12 @@ class MapKeyTypeException(MichelsonTypecheckerException):
   - map type: {map_type}
         """
 
+
 class MapValueTypeException(MichelsonTypecheckerException):
     def __init__(self, value_type, map_type, extra_msg="", lineno=0):
-        self.message = f"""Value type incompatible with map type on GET instruction:
+        self.message = "Value type incompatible with map type"
+        self.message += f" on GET instruction at line {lineno}:"
+        self.message += f"""
   - value type: {value_type}
   - map type: {map_type}
         """
@@ -110,11 +131,14 @@ class ContractReturnTypeException(MichelsonTypecheckerException):
         self.message = f"""The contract is not returning an (operation list, storage_type) pair:
   - actual return type: {actual_return_type}
   - expected return type: {expected_return_type}
-        """
+        """  # noqa: E501
+
 
 class PushTypeException(MichelsonTypecheckerException):
     def __init__(self, lineno=0):
-        self.message = "Can only PUSH one of [int, nat, string, mutez, timestamp, address]"
+        self.message = (
+            "Can only PUSH one of [int, nat, string, mutez, timestamp, address]"
+        )
 
 
 class LambdaArgumentTypeException(MichelsonTypecheckerException):
@@ -124,11 +148,10 @@ class LambdaArgumentTypeException(MichelsonTypecheckerException):
   - expected argument type: {expected_argument_type}
         """
 
+
 class StackLengthException(MichelsonTypecheckerException):
     pass
 
 
 class InvalidMichelsonException(MichelsonTypecheckerException):
     pass
-
-
